<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="fi">
<context>
    <name>App.About</name>
    <message>
        <source>System Monitor</source>
        <translation>Järjestelmän valvonta</translation>
    </message>
    <message>
        <source>System Monitor is a tool to monitor realtime system load, view and control processes and services running on your system.</source>
        <translation>Järjestelmän valvonta on työkalu, jolla voidaan seurata järjestelmän reaaliaikaista kuormitusta, tarkastella, hallita käynnissä olevia prosesseja ja palveluita.</translation>
    </message>
</context>
<context>
    <name>BaseDetailViewWidget</name>
    <message>
        <source>Hide details</source>
        <translation>Piilota tiedot</translation>
    </message>
    <message>
        <source>Overall utilization</source>
        <translation>Käyttöaste</translation>
    </message>
    <message>
        <source>Individual utilization</source>
        <translation>Käyttö</translation>
    </message>
</context>
<context>
    <name>BlockDevItemWidget</name>
    <message>
        <source>Read</source>
        <translation>Luku</translation>
    </message>
    <message>
        <source>Write</source>
        <translation>Kirjoitus</translation>
    </message>
</context>
<context>
    <name>CPUDetailGrapTableItem</name>
    <message>
        <source>60 seconds</source>
        <translation>60 sekuntia</translation>
    </message>
</context>
<context>
    <name>CPUInfoModel</name>
    <message>
        <source>%1 days %2 hours %3 minutes</source>
        <translation>%1 pv %2 t %3 min</translation>
    </message>
</context>
<context>
    <name>CPUSummaryTableModel</name>
    <message>
        <source>Utilization</source>
        <translation>Käyttö</translation>
    </message>
    <message>
        <source>Current frequency</source>
        <translation>Nykyinen taajuus</translation>
    </message>
    <message>
        <source>Frequency</source>
        <translation>Taajuus</translation>
    </message>
    <message>
        <source>Vendor</source>
        <translation>Valmistaja</translation>
    </message>
    <message>
        <source>Sockets</source>
        <translation>Korttipaikat</translation>
    </message>
    <message>
        <source>Logical processors</source>
        <translation>Loogiset suorittimet</translation>
    </message>
    <message>
        <source>Virtualization</source>
        <translation>Virtualisointi</translation>
    </message>
    <message>
        <source>L1i cache</source>
        <translation>L1i-välimuisti</translation>
    </message>
    <message>
        <source>L1d cache</source>
        <translation>L1d-välimuisti</translation>
    </message>
    <message>
        <source>L2 cache</source>
        <translation>L2-välimuisti</translation>
    </message>
    <message>
        <source>L3 cache</source>
        <translation>L3-välimuisti</translation>
    </message>
    <message>
        <source>Load average</source>
        <translation>Kuormituksen keskiarvo</translation>
    </message>
    <message>
        <source>File descriptors</source>
        <translation>Tiedoston kuvaus</translation>
    </message>
    <message>
        <source>Processes</source>
        <translation>Prosessit</translation>
    </message>
    <message>
        <source>Threads</source>
        <translation>Säikeet</translation>
    </message>
    <message>
        <source>Host name</source>
        <translation>Koneen nimi</translation>
    </message>
    <message>
        <source>OS type</source>
        <translation>Järjestelmä</translation>
    </message>
    <message>
        <source>Version</source>
        <translation>Versio</translation>
    </message>
    <message>
        <source>Up time</source>
        <translation>Käyntiaika</translation>
    </message>
</context>
<context>
    <name>ChartViewWidget</name>
    <message>
        <source>60 seconds</source>
        <translation>60 sekuntia</translation>
    </message>
</context>
<context>
    <name>Common.Search</name>
    <message>
        <source>No search results</source>
        <translation>Ei hakutuloksia</translation>
    </message>
</context>
<context>
    <name>CompactCpuMonitor</name>
    <message>
        <source>Details</source>
        <translation>Tiedot</translation>
    </message>
</context>
<context>
    <name>CpuMonitor</name>
    <message>
        <source>Details</source>
        <translation>Tiedot</translation>
    </message>
</context>
<context>
    <name>DBus.Unit.Active.State</name>
    <message>
        <source>active</source>
        <translation>aktiivinen</translation>
    </message>
    <message>
        <source>reloading</source>
        <translation>lataa-uudelleen</translation>
    </message>
    <message>
        <source>inactive</source>
        <translation>passiivinen</translation>
    </message>
    <message>
        <source>failed</source>
        <translation>epäonnistui</translation>
    </message>
    <message>
        <source>activating</source>
        <translation>kytketään</translation>
    </message>
    <message>
        <source>deactivating</source>
        <translation>katkaistaan</translation>
    </message>
</context>
<context>
    <name>DBus.Unit.Load.State</name>
    <message>
        <source>stub</source>
        <translation>tynkä</translation>
    </message>
    <message>
        <source>not-found</source>
        <translation>ei-löydy</translation>
    </message>
    <message>
        <source>bad-setting</source>
        <translation>huono-asetus</translation>
    </message>
    <message>
        <source>error</source>
        <translation>virhe</translation>
    </message>
    <message>
        <source>merged</source>
        <translation>yhdistetty</translation>
    </message>
    <message>
        <source>masked</source>
        <translation>peitetty</translation>
    </message>
    <message>
        <source>loaded</source>
        <translation>ladattu</translation>
    </message>
</context>
<context>
    <name>DBus.Unit.Startup.Mode</name>
    <message>
        <source>N/A</source>
        <translation>N/A</translation>
    </message>
    <message>
        <source>Auto</source>
        <translation>Automaatti</translation>
    </message>
    <message>
        <source>Manual</source>
        <translation>Manuaalinen</translation>
    </message>
</context>
<context>
    <name>DBus.Unit.State</name>
    <message>
        <source>enabled</source>
        <translation>käytössä</translation>
    </message>
    <message>
        <source>disabled</source>
        <translation>estetty</translation>
    </message>
    <message>
        <source>static</source>
        <translation>staattinen</translation>
    </message>
    <message>
        <source>transient</source>
        <translation>Ohimenevä</translation>
    </message>
    <message>
        <source>indirect</source>
        <translation>epäsuora</translation>
    </message>
    <message>
        <source>enabled-runtime</source>
        <translation>käytössä-runtime</translation>
    </message>
    <message>
        <source>masked</source>
        <translation>peitetty</translation>
    </message>
    <message>
        <source>generated</source>
        <translation>tuotettu</translation>
    </message>
</context>
<context>
    <name>DBus.Unit.Sub.State</name>
    <message>
        <source>dead</source>
        <translation>eloton</translation>
    </message>
    <message>
        <source>start-pre</source>
        <translation>käynnistä-pre</translation>
    </message>
    <message>
        <source>start</source>
        <translation>käynnistä</translation>
    </message>
    <message>
        <source>start-post</source>
        <translation>käynnistä-posti</translation>
    </message>
    <message>
        <source>running</source>
        <translation>ajossa</translation>
    </message>
    <message>
        <source>exited</source>
        <translation>poistunut</translation>
    </message>
    <message>
        <source>reload</source>
        <translation>lataa-uudestaan</translation>
    </message>
    <message>
        <source>stop</source>
        <translation>pysäytä</translation>
    </message>
    <message>
        <source>stop-watchdog</source>
        <translation>pysäytä-watchdog</translation>
    </message>
    <message>
        <source>stop-sigterm</source>
        <translation>pysäytä-sigterm</translation>
    </message>
    <message>
        <source>stop-sigkill</source>
        <translation>pysäytä-sigkill</translation>
    </message>
    <message>
        <source>stop-post</source>
        <translation>pysäytä-posti</translation>
    </message>
    <message>
        <source>final-sigterm</source>
        <translation>lopullinen-sigterm</translation>
    </message>
    <message>
        <source>final-sigkill</source>
        <translation>lopullinen-sigkill</translation>
    </message>
    <message>
        <source>failed</source>
        <translation>Epäonnistui</translation>
    </message>
    <message>
        <source>auto-restart</source>
        <translation>autom-käynnistys</translation>
    </message>
</context>
<context>
    <name>DeailTableModel</name>
    <message>
        <source>Used</source>
        <translation>Käytetty</translation>
    </message>
    <message>
        <source>Available</source>
        <translation>Saatavilla</translation>
    </message>
    <message>
        <source>Shared</source>
        <translation>Jaettu</translation>
    </message>
    <message>
        <source>Cached</source>
        <translation>Välimuisti</translation>
    </message>
    <message>
        <source>Buffers</source>
        <translation>Puskurit</translation>
    </message>
    <message>
        <source>Cached swap</source>
        <translation>Välimuisti swap</translation>
    </message>
    <message>
        <source>Active</source>
        <translation>Aktiivinen</translation>
    </message>
    <message>
        <source>Inactive</source>
        <translation>Toimeton</translation>
    </message>
    <message>
        <source>Dirty</source>
        <translation>Huono</translation>
    </message>
    <message>
        <source>Mapped</source>
        <translation>Kartoitettu </translation>
    </message>
    <message>
        <source>Total swap</source>
        <translation>Yhteensä swap</translation>
    </message>
    <message>
        <source>Free swap</source>
        <translation>Vapaa swap</translation>
    </message>
    <message>
        <source>Slab</source>
        <translation>Laatta</translation>
    </message>
</context>
<context>
    <name>DeailTableModelBlock</name>
    <message>
        <source>Model</source>
        <translation>Malli</translation>
    </message>
    <message>
        <source>Read speed</source>
        <translation>Lukunopeus</translation>
    </message>
    <message>
        <source>Write speed</source>
        <translation>Kirjoitusnopeus</translation>
    </message>
    <message>
        <source>Capacity</source>
        <translation>Kapasiteetti</translation>
    </message>
    <message>
        <source>Sectors read</source>
        <translation>Luetut sektorit</translation>
    </message>
    <message>
        <source>Reads/s</source>
        <translation>Luku/s</translation>
    </message>
    <message>
        <source>Sectors read/s</source>
        <translation>Luetut sektorit/s</translation>
    </message>
    <message>
        <source>Reads merged/s</source>
        <translation>Yhdistetty luku/s</translation>
    </message>
    <message>
        <source>Sectors written</source>
        <translation>Kirjoitetut sektorit</translation>
    </message>
    <message>
        <source>Writes completed </source>
        <translation>Kirjoitus valmis</translation>
    </message>
    <message>
        <source>Writes merged</source>
        <translation>Yhdistetty kirjoitus</translation>
    </message>
    <message>
        <source>Writes/s</source>
        <translation>Kirjoitus/s</translation>
    </message>
    <message>
        <source>Sectors written/s</source>
        <translation>Kirjoitetut sektorit/s</translation>
    </message>
    <message>
        <source>Writes merged/s</source>
        <translation>Yhdistetty kirjoitus/s</translation>
    </message>
</context>
<context>
    <name>Error.Dialog</name>
    <message>
        <source>OK</source>
        <comment>button</comment>
        <translation>OK</translation>
    </message>
</context>
<context>
    <name>Help.Shortcut.System</name>
    <message>
        <source>System</source>
        <translation>Järjestelmä</translation>
    </message>
    <message>
        <source>Display shortcuts</source>
        <translation>Näytä pikakuvakkeet</translation>
    </message>
</context>
<context>
    <name>Kill.Process.Dialog</name>
    <message>
        <source>Ending this process may cause data loss.
Are you sure you want to continue?</source>
        <translation>Tämän prosessin lopettaminen voi aiheuttaa tietojen häviämistä.
Haluatko varmasti jatkaa?</translation>
    </message>
    <message>
        <source>End process</source>
        <translation>Lopeta prosessi</translation>
    </message>
    <message>
        <source>Force ending this process may cause data loss.
Are you sure you want to continue?</source>
        <translation>Tämän prosessin lopettaminen pakottamalla voi aiheuttaa tietojen häviämistä.
Haluatko varmasti jatkaa?</translation>
    </message>
    <message>
        <source>Force ending this application may cause data loss.
Are you sure you want to continue?</source>
        <translation>Sovelluksen lopettaminen voi aiheuttaa tietojen häviämisen.
Haluatko varmasti jatkaa?</translation>
    </message>
    <message>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>Peru</translation>
    </message>
    <message>
        <source>Force End</source>
        <comment>button</comment>
        <translation>Pakota lopetus</translation>
    </message>
    <message>
        <source>End</source>
        <comment>button</comment>
        <translation>Loppu</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>Settings</source>
        <translation>Asetukset</translation>
    </message>
</context>
<context>
    <name>MemStatViewWidget</name>
    <message>
        <source>Size</source>
        <translation>Koko</translation>
    </message>
</context>
<context>
    <name>NetInfoDetailItemDelegate</name>
    <message>
        <source>IP address:</source>
        <translation>IP osoite:</translation>
    </message>
    <message>
        <source>Netmask:</source>
        <translation>Verkkopeite:</translation>
    </message>
    <message>
        <source>Broadcast:</source>
        <translation>Lähtevä:</translation>
    </message>
    <message>
        <source>Prefixlen:</source>
        <translation>Etuliite:</translation>
    </message>
    <message>
        <source>Scope:</source>
        <translation>Laajuus:</translation>
    </message>
</context>
<context>
    <name>NetInfoModel</name>
    <message>
        <source>Connection type</source>
        <translation>Yhteystyyppi</translation>
    </message>
    <message>
        <source>ESSID</source>
        <translation>ESSID</translation>
    </message>
    <message>
        <source>Link quality</source>
        <translation>Linkin laatu</translation>
    </message>
    <message>
        <source>Signal strength</source>
        <translation>Signaalin voimakkuus</translation>
    </message>
    <message>
        <source>Noise level</source>
        <translation>Melutaso</translation>
    </message>
    <message>
        <source>MAC</source>
        <translation>MAC</translation>
    </message>
    <message>
        <source>Bandwidth</source>
        <translation>Kaista</translation>
    </message>
    <message>
        <source>RX packets</source>
        <translation>RX paketit</translation>
    </message>
    <message>
        <source>RX bytes</source>
        <translation>RX tavua</translation>
    </message>
    <message>
        <source>RX errors</source>
        <translation>RX virheet</translation>
    </message>
    <message>
        <source>RX dropped</source>
        <translation>RX pudotetut</translation>
    </message>
    <message>
        <source>RX overruns</source>
        <translation>RX ylitykset</translation>
    </message>
    <message>
        <source>RX frame</source>
        <translation>RX kehys</translation>
    </message>
    <message>
        <source>TX packets</source>
        <translation>TX paketit</translation>
    </message>
    <message>
        <source>TX bytes</source>
        <translation>TX tavua</translation>
    </message>
    <message>
        <source>TX errors</source>
        <translation>TX virheet</translation>
    </message>
    <message>
        <source>TX overruns</source>
        <translation>TX ylitykset</translation>
    </message>
    <message>
        <source>TX carrier</source>
        <translation>TX kantoaalto</translation>
    </message>
    <message>
        <source>IPv4</source>
        <translation>IPv4</translation>
    </message>
    <message>
        <source>IPv6</source>
        <translation>IPv6</translation>
    </message>
    <message>
        <source>TX dropped</source>
        <translation>TX pudotetut</translation>
    </message>
</context>
<context>
    <name>Process.Attributes.Dialog</name>
    <message>
        <source>Command line</source>
        <translation>Komentorivi</translation>
    </message>
    <message>
        <source>Start time</source>
        <translation>Aloitusaika</translation>
    </message>
    <message>
        <source>Name</source>
        <translation>Nimi</translation>
    </message>
</context>
<context>
    <name>Process.Choose.Window.Dialog</name>
    <message>
        <source>Click the application you want to end</source>
        <translation>Napsauta sovellusta, jonka haluat lopettaa</translation>
    </message>
</context>
<context>
    <name>Process.Graph.Title</name>
    <message>
        <source>Memory</source>
        <translation>Muisti </translation>
    </message>
    <message>
        <source>Receive</source>
        <translation>Saatu</translation>
    </message>
</context>
<context>
    <name>Process.Graph.View</name>
    <message>
        <source>CPU</source>
        <translation>Kuorma</translation>
    </message>
    <message>
        <source>Disk read</source>
        <translation>Luku</translation>
    </message>
    <message>
        <source>Disk write</source>
        <translation>Kirjoitus</translation>
    </message>
    <message>
        <source>Memory</source>
        <translation>Muisti </translation>
    </message>
    <message>
        <source>Swap</source>
        <translation>Swap </translation>
    </message>
    <message>
        <source>Not enabled</source>
        <translation>Ei käytössä</translation>
    </message>
    <message>
        <source>Download</source>
        <translation>Lataus</translation>
    </message>
    <message>
        <source>Upload</source>
        <translation>Lähetys</translation>
    </message>
    <message>
        <source>Network</source>
        <translation>Verkko</translation>
    </message>
    <message>
        <source>Total Received</source>
        <translation>Saatu</translation>
    </message>
    <message>
        <source>Total Sent</source>
        <translation>Lähetetty</translation>
    </message>
    <message>
        <source>Send</source>
        <translation>Lähetys</translation>
    </message>
    <message>
        <source>Disks</source>
        <translation>Levyt</translation>
    </message>
</context>
<context>
    <name>Process.Priority</name>
    <message>
        <source>Very high</source>
        <translation>Erittäin korkea</translation>
    </message>
    <message>
        <source>High</source>
        <translation>Korkea</translation>
    </message>
    <message>
        <source>Normal</source>
        <translation>Normaali</translation>
    </message>
    <message>
        <source>Low</source>
        <translation>Matala</translation>
    </message>
    <message>
        <source>Very low</source>
        <translation>Erittäin matala</translation>
    </message>
    <message>
        <source>Custom</source>
        <translation>Mukautettu</translation>
    </message>
    <message>
        <source>Invalid</source>
        <translation>Viallinen</translation>
    </message>
    <message>
        <source>PID: %1, Error: [%2] %3</source>
        <translation>PID: %1, Virhe: [%2] %3</translation>
    </message>
    <message>
        <source>Failed to change process priority</source>
        <translation>Prosessin prioriteettia ei voitu muuttaa</translation>
    </message>
</context>
<context>
    <name>Process.Show.Mode</name>
    <message>
        <source>Applications</source>
        <translation>Sovellukset</translation>
    </message>
    <message>
        <source>My processes</source>
        <translation>Minun prosessini</translation>
    </message>
    <message>
        <source>All processes</source>
        <translation>Kaikki prosessit</translation>
    </message>
</context>
<context>
    <name>Process.Loading</name>
    <message>
        <source>Loading</source>
        <translation>Ladataan</translation>
    </message>
</context>
<context>
    <name>Process.Signal</name>
    <message>
        <source>Failed to pause process</source>
        <translation>Prosessin pysäytys epäonnistui</translation>
    </message>
    <message>
        <source>Failed to resume process</source>
        <translation>Prosessin jatkaminen epäonnistui</translation>
    </message>
    <message>
        <source>Failed to kill process</source>
        <translation>Prosessin tappaminen epäonnistui</translation>
    </message>
    <message>
        <source>Unknown error</source>
        <translation>Tuntematon virhe</translation>
    </message>
    <message>
        <source>Failed in sending signal to process</source>
        <translation>Viestin lähettäminen käsittelyyn epäonnistui</translation>
    </message>
    <message>
        <source>Failed to end process</source>
        <translation>Prosessin lopetus epäonnistui</translation>
    </message>
</context>
<context>
    <name>Process.Summary</name>
    <message>
        <source>(%1 applications and %2 processes are running)</source>
        <translation>(%1 sovellusta ja %2 prosessia on käynnissä)</translation>
    </message>
</context>
<context>
    <name>Process.Table</name>
    <message>
        <source>No response</source>
        <translation>Ei vastausta</translation>
    </message>
    <message>
        <source>Suspend</source>
        <translation>Keskeytä</translation>
    </message>
    <message>
        <source>Tray</source>
        <translation>Valikko</translation>
    </message>
</context>
<context>
    <name>Process.Table.Context.Menu</name>
    <message>
        <source>View command location</source>
        <translation>Näytä komennon sijainti</translation>
    </message>
    <message>
        <source>Properties</source>
        <translation>Ominaisuudet</translation>
    </message>
    <message>
        <source>End process</source>
        <translation>Lopeta prosessi</translation>
    </message>
    <message>
        <source>Resume process</source>
        <translation>Jatka prosessia</translation>
    </message>
    <message>
        <source>Kill process</source>
        <translation>Tapa prosessi</translation>
    </message>
    <message>
        <source>Change priority</source>
        <translation>Vaihda prioriteetti</translation>
    </message>
    <message>
        <source>Suspend process</source>
        <translation>Keskeytä prosessi</translation>
    </message>
</context>
<context>
    <name>Process.Table.Custom.Priority.Dialog</name>
    <message>
        <source>Custom Priority</source>
        <translation>Muokattu prioriteetti</translation>
    </message>
    <message>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>Peru</translation>
    </message>
    <message>
        <source>Change</source>
        <comment>button</comment>
        <translation>Muutos</translation>
    </message>
</context>
<context>
    <name>Process.Table.Header</name>
    <message>
        <source>Name</source>
        <translation>Nimi</translation>
    </message>
    <message>
        <source>CPU</source>
        <translation>Prosessori</translation>
    </message>
    <message>
        <source>Memory</source>
        <translation>Muisti</translation>
    </message>
    <message>
        <source>Disk write</source>
        <translation>Kirjoitus</translation>
    </message>
    <message>
        <source>Disk read</source>
        <translation>Luku</translation>
    </message>
    <message>
        <source>Download</source>
        <translation>Lataus</translation>
    </message>
    <message>
        <source>Upload</source>
        <translation>Lähetys</translation>
    </message>
    <message>
        <source>PID</source>
        <translation>PID</translation>
    </message>
    <message>
        <source>User</source>
        <translation>Käyttäjä</translation>
    </message>
    <message>
        <source>Nice</source>
        <translation>Nice</translation>
    </message>
    <message>
        <source>Priority</source>
        <translation>Prioriteetti</translation>
    </message>
    <message>
        <source>Shared memory</source>
        <translation>Jaettu muisti</translation>
    </message>
    <message>
        <source>Virtual memory</source>
        <translation>Virtuaalinen muisti</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Not support</source>
        <translation>Ei tukea</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Asetukset</translation>
    </message>
    <message>
        <source>System Protection</source>
        <translation>Järjestelmän suojaus</translation>
    </message>
    <message>
        <source>Show warnings when the usage exceeds the thresholds</source>
        <translation>Näytä varoitukset, kun käyttö ylittää kynnysarvot</translation>
    </message>
    <message>
        <source>Notifications</source>
        <translation>Ilmoitukset</translation>
    </message>
    <message>
        <source>CPU warning threshold (%)</source>
        <translation>CPU varoituskynnys (%)</translation>
    </message>
    <message>
        <source>Memory warning threshold (%)</source>
        <translation>Muistin varoituskynnys (%)</translation>
    </message>
    <message>
        <source>Warning interval (min)</source>
        <translation>Varoitusväli (min)</translation>
    </message>
</context>
<context>
    <name>Service.Action.Set.Startup.Mode</name>
    <message>
        <source>Failed to set service startup type</source>
        <translation>Palvelun käynnistystyypin määrittäminen epäonnistui</translation>
    </message>
    <message>
        <source>Error: Failed to set service startup type due to the crashed sub process.</source>
        <translation>Virhe: Palvelun käynnistystyypin määrittäminen epäonnistui kaatuneen alaprosessin vuoksi.</translation>
    </message>
</context>
<context>
    <name>Service.Instance.Name.Dialog</name>
    <message>
        <source>Service instance name</source>
        <translation>Palvelun esiintymän nimi</translation>
    </message>
    <message>
        <source>OK</source>
        <comment>button</comment>
        <translation>OK</translation>
    </message>
    <message>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>Peru</translation>
    </message>
</context>
<context>
    <name>Service.Table.Context.Menu</name>
    <message>
        <source>Refresh</source>
        <translation>Virkistä</translation>
    </message>
    <message>
        <source>Start</source>
        <translation>Aloita</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>Pysäytä</translation>
    </message>
    <message>
        <source>Restart</source>
        <translation>Uudelleen</translation>
    </message>
    <message>
        <source>Auto</source>
        <translation>Automaatti</translation>
    </message>
    <message>
        <source>Manual</source>
        <translation>Manuaalinen</translation>
    </message>
    <message>
        <source>Startup type</source>
        <translation>Käynnistyksen tyyppi</translation>
    </message>
</context>
<context>
    <name>Service.Table.Header</name>
    <message>
        <source>Name</source>
        <translation>Nimi</translation>
    </message>
    <message>
        <source>Load</source>
        <translation>Lataus</translation>
    </message>
    <message>
        <source>Active</source>
        <translation>Aktiivinen</translation>
    </message>
    <message>
        <source>Sub</source>
        <translation>Nyt</translation>
    </message>
    <message>
        <source>State</source>
        <translation>Tila</translation>
    </message>
    <message>
        <source>Description</source>
        <translation>Kuvaus</translation>
    </message>
    <message>
        <source>PID</source>
        <translation>PID</translation>
    </message>
    <message>
        <source>Startup Type</source>
        <translation>Käynnistyksen tyyppi</translation>
    </message>
</context>
<context>
    <name>SystemProtectionSetting</name>
    <message>
        <source>Settings</source>
        <translation>Asetukset</translation>
    </message>
    <message>
        <source>(Modifiable)</source>
        <translation>(Muokattavissa)</translation>
    </message>
    <message>
        <source>Range: %1-%2</source>
        <translation>Alue: %1-%2</translation>
    </message>
</context>
<context>
    <name>Title.Bar.Context.Menu</name>
    <message>
        <source>Force end application</source>
        <translation>Pakota sovelluksen lopettaminen</translation>
    </message>
    <message>
        <source>Expand</source>
        <translation>Laajenna</translation>
    </message>
    <message>
        <source>Compact</source>
        <translation>Tiivis</translation>
    </message>
    <message>
        <source>View</source>
        <translation>Katso</translation>
    </message>
</context>
<context>
    <name>Title.Bar.Search</name>
    <message>
        <source>Search</source>
        <translation>Hae</translation>
    </message>
</context>
<context>
    <name>Title.Bar.Switch</name>
    <message>
        <source>Processes</source>
        <translation>Prosessit</translation>
    </message>
    <message>
        <source>Services</source>
        <translation>Palvelut</translation>
    </message>
</context>
</TS>
